@@ -10,8 +10,8 @@ use strict;
 
 ########################################################
 # Specify version and build-date:
-my $Version = '7.5.4';
-my $VDate = '07/22/20';
+my $Version = '7.5.6';
+my $VDate = '07/23/21';
 
 #######################################################
 # Logwatch was originally written by:
@@ -292,7 +292,7 @@ my $out_foot ='';
 if ( $Config{'encode'} eq "base64" ) {
    eval "require MIME::Base64";
    if ($@) {
-      print STDERR "No MIME::Base64 installed can not use --encode\n";
+      print STDERR "No MIME::Base64 installed; can not use --encode\n";
     } else {
       import MIME::Base64;
    }
@@ -1135,7 +1135,7 @@ sub Usage () {
    print "--service <name>: *Name of a service definition to report on.\n";
    print "--output <output type>: Report Output - stdout [default], mail, file.\n"; #8.0
    print "--format <formatting>: Report Format - text [default], html.\n"; #8.0
-   print "--encode <encoding>: Encoding to use - none [default], base64.\n"; #8.0
+   print "--encode <encoding>: Encoding to use - none [default], base64, 7bit, 8bit [same as 'none'].\n"; #8.0
    print "--mailto <addr>: Mail report to <addr>.\n";
    print "--archives: Use archived log files too.\n";
    print "--filename <filename>: Used to specify they filename to save to. --filename <filename> [Forces output to file].\n";
@@ -1201,8 +1201,10 @@ sub initprint {
          #Config{encode} switch
          if ( $Config{'encode'} eq "base64" ) {
             $out_mime .= "Content-transfer-encoding: base64\n";
-         } else {
+         } elsif ( $Config{'encode'} eq "7bit" ) {
             $out_mime .= "Content-Transfer-Encoding: 7bit\n";
+         } else {
+            $out_mime .= "Content-Transfer-Encoding: 8bit\n";
          }
          #Config{output} html
          if ( $Config{'format'} eq "html" ) {
@@ -1513,7 +1515,6 @@ sub parselogs {
 #Printing starts here $out_mime $out_head $out_reference $out_body $out_foot
    if (defined fileno OUTFILE) {
       print OUTFILE $out_mime if $out_mime;
-      if ( $Config{'encode'} eq "base64" ) {
          my $out = '';
          $out .= $out_head if $out_head;
          $out .= $out_reference if $out_reference;
@@ -1522,15 +1523,10 @@ sub parselogs {
             $out_body{$_} = ''; #We should track this down out_body could be an array instead also -mgt
          }
          $out .= $out_foot if $out_foot;
+      if ( $Config{'encode'} eq "base64" ) {
          print OUTFILE encode_base64($out);
       } else {
-         print OUTFILE $out_head if $out_head;
-         print OUTFILE $out_reference if $out_reference;
-         foreach ( 0 .. $index_par ) {
-            print OUTFILE $out_body{$_} if defined( $out_body{$_} );
-            $out_body{$_} = '';
-         }
-         print OUTFILE $out_foot if $out_foot;
+         print OUTFILE $out;
       }
    }
 #ends here
